@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Base;
 
-our $DATE = '2019-01-14'; # DATE
-our $VERSION = '1.817'; # VERSION
+our $DATE = '2019-05-25'; # DATE
+our $VERSION = '1.818'; # VERSION
 
 use 5.010001;
 use strict;
@@ -1437,7 +1437,7 @@ sub display_result {
 
     my $handle = $r->{output_handle};
 
-    my $sch = $meta->{result}{schema};
+    my $sch = $meta->{result}{schema} // $resmeta->{schema};
     my $type = Data::Sah::Util::Type::get_type($sch) // '';
 
     if ($resmeta->{stream} // $meta->{result}{stream}) {
@@ -1688,7 +1688,7 @@ Perinci::CmdLine::Base - Base class for Perinci::CmdLine{::Classic,::Lite}
 
 =head1 VERSION
 
-This document describes version 1.817 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2019-01-14.
+This document describes version 1.818 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2019-05-25.
 
 =head1 DESCRIPTION
 
